@@ -972,6 +972,25 @@ class Elout(BinoutData):
         """
         BinoutData.__init__(self, binout, logger, dynasaur_definitions, 'elout')
 
+class Abstat(BinoutData):
+    # applies for beam elements!
+    DATA_CHANNEL_TYPES = ['dm_dt_out', 'pressure', 'internal_energy', 'density', 'surface_area', 'dm_dt_in', 'dm_dt_outp',
+                          'reaction', 'volume', 'gas_temp', 'total_mass', 'dm_dt_outv']
+
+    ids_name = "ids"
+
+    def __init__(self, binout, logger, dynasaur_definitions):
+        """
+        Initialization i.e. call BinoutData constructor
+
+        :param: binout
+        :param: logger
+        :param: dynasaur definition
+
+        :return:
+        """
+        BinoutData.__init__(self, binout, logger, dynasaur_definitions, 'abstat')
+
 
 class Glstat(BinoutData):
     """
