@@ -7,7 +7,7 @@ from ..utils.constants import VPSDataConstant, DataChannelTypesNodout, DataChann
 class VPSData:
 
     def __init__(self, vps_file_path):
-        # print(vps_file_path)
+
         self.file_data = {}             # should be wrapped to binout data.
 
         self._vps_file_path = vps_file_path
@@ -25,22 +25,40 @@ class VPSData:
                 if node.parent.name.split("/")[5] in [VPSDataConstant.NODE]:
                     self._set_node_elements(node)
 
+                elif node.parent.name.split("/")[5] in [VPSDataConstant.SECTION]:
+                    if node.parent.name.split("/")[5] == VPSDataConstant.SECTION:
+                        if VPSDataConstant.SECFORC not in self._d.keys():
+                            self._d[VPSDataConstant.SECFORC] = ["ids", "time"]
+                            DATA_CHANNEL_TYPES = ['x_force', 'y_force', 'z_force', 'total_force', 'x_moment', 'y_moment', 'z_moment',
+                                                  'total_moment', 'x_centroid', 'y_centroid', 'z_centroid', 'area']
+                        idx_of_data = node.parent.name.split("/").index(node.parent.name.split("/")[5]) + 1
+                        # TODO
+                        # print("*******************************************")
+                        # print(node.parent.name.split("/")[idx_of_data])
+                        # print("-------------------------------------------")
+                        if node.parent.name.split("/")[idx_of_data] == VPSDataConstant.SECTION_CENTRE_POSITION:
+                            self._d[VPSDataConstant.SECFORC].extend([DataChannelTypesSecforc.X_CENTROID,
+                                                                     DataChannelTypesSecforc.Y_CENTROID,
+                                                                     DataChannelTypesSecforc.Z_CENTROID])
+                        elif node.parent.name.split("/")[idx_of_data] == VPSDataConstant.SECTION_FORCE:
+                            self._d[VPSDataConstant.SECFORC].extend([DataChannelTypesSecforc.X_FORCE,
+                                                                     DataChannelTypesSecforc.Y_FORCE,
+                                                                     DataChannelTypesSecforc.Z_FORCE])
+                        elif node.parent.name.split("/")[idx_of_data] == VPSDataConstant.SECTION_MOMENT:
+                            self._d[VPSDataConstant.SECFORC].extend([DataChannelTypesSecforc.X_MOMENT,
+                                                                     DataChannelTypesSecforc.Y_MOMENT,
+                                                                     DataChannelTypesSecforc.Z_MOMENT])
 
                 elif node.parent.name.split("/")[5] in [VPSDataConstant.SECTION]:
                     self._set_section_elements(node)
 
-    def _read_id_definitions(self, id_file_path):
-        print(id_file_path)
-
     def _args_to_data(self, args):
         data_type = ""
         data_channel = ""
 
         if args[1] == "time":
-            print("READ TIME")
             with h5py.File(self._vps_file_path, 'r') as f:
                 path = "/CSMEXPL/multistate/TIMESERIES1/multientityresults/MODEL/TIME/ZONE1_set1/erfblock/entid"
-                print(f[path][()])
                 path = "/CSMEXPL/multistate/TIMESERIES1/multientityresults/MODEL/TIME/ZONE1_set1/erfblock/res"
                 return(f[path][()][:,0,0])
 
@@ -75,8 +93,6 @@ class VPSData:
         #
         for i in argv:
             read_argv.append(i)
-        print("Try to read:")
-        print(read_argv)
         assert 0 <= len(read_argv) <= 4
 
         if len(read_argv) == 0:
