@@ -15,8 +15,10 @@ from ..data.data_container import DataContainer
 from ..data.vps import VPSData
 from ..data.madymo import MadymoData
 
+
 class Plugin(object):
-    def __init__(self, path_to_def_file, path_def_file_id, data_source, name, user_function_object=None, volume_path=None, code_type="LS-DYNA"):
+    def __init__(self, path_to_def_file, path_def_file_id, data_source, name, user_function_object=None,
+                 volume_path=None, code_type="LS-DYNA"):
         """
         Initialization class constructor
 
@@ -34,20 +36,23 @@ class Plugin(object):
         self._dynasaur_definitions.read_def(path_to_def_file)
         self._dynasaur_definitions.read_def(path_def_file_id)
         self._user_function = user_function_object
-        #self._code_type = self._dynasaur_definitions.get_code()
+        # self._code_type = self._dynasaur_definitions.get_code()
 
         if code_type == "LS-DYNA":
             binout = Binout(data_source)
-            DataContainer.init_all_data_sources(binout, self._logger, self._dynasaur_definitions, volume_path=volume_path)
+            DataContainer.init_all_data_sources(binout, self._logger, self._dynasaur_definitions,
+                                                volume_path=volume_path)
         elif code_type == "VPS":
             vps_data = VPSData(vps_file_path=data_source)
-            DataContainer.init_all_data_sources(vps_data, self._logger, self._dynasaur_definitions, volume_path=volume_path)
+            DataContainer.init_all_data_sources(vps_data, self._logger, self._dynasaur_definitions,
+                                                volume_path=volume_path)
 
         elif code_type == "MADYMO":
             madymo_data = MadymoData(madymo_file_path=data_source)
-            DataContainer.init_all_data_sources(madymo_data, self._logger, self._dynasaur_definitions, volume_path=volume_path)
+            DataContainer.init_all_data_sources(madymo_data, self._logger, self._dynasaur_definitions,
+                                                volume_path=volume_path)
         else:
-            #TODO: Error msg
+            # TODO: Error msg
             print("Not valid code type")
             return
 
@@ -61,6 +66,53 @@ class Plugin(object):
         # ensure unique timestamps
         time.sleep(1)
 
+    def _check_if_user_function(self, function_name):
+        """
+        :param function_name:
+        :return bool:
+        """
+        attributes = inspect.getmembers(self._user_function, predicate=inspect.isfunction)
+        if function_name in [att[0] for att in attributes]:
+            return True
+        return False
+
+    @staticmethod
+    def _kwargs_from_param_dict(param_dict, units):
+        """
+
+        :param param_dict:
+        :return:
+        """
+        kwargs = {}
+        for key in param_dict:
+            kwargs[key] = param_dict[key]
+
+        kwargs["units"] = units
+        return kwargs
+
+    def _call_standard_function(self, function_name, param_dict):
+        """
+
+        :param function_name:
+        :param param_dict:
+        :return:
+        """
+        kwargs = Plugin._kwargs_from_param_dict(param_dict, self._units)
+        if self._user_function is not None:
+            if self._check_if_user_function(function_name):
+                function = getattr(self._user_function, function_name)
+                return function(param_dict, self._units)
+
+        if function_name not in StandardFunction.__dict__.keys():
+            self._logger.emit(LOGConstants.ERROR[0], function_name + " is not a standard function!")
+            self._logger.emit(LOGConstants.ERROR[0], "Implemented functions are :\n" + "\n".join(
+                [i for i in StandardFunction.__dict__.keys() if not i.startswith("__")]))
+
+            return None
+        else:
+            func_ptr = StandardFunction.__dict__[function_name]
+            return func_ptr.__func__(**kwargs)
+
     def _get_data_from_dynasaur_json(self, json_object, data_offsets):
         """
 
@@ -81,127 +133,32 @@ class Plugin(object):
                         continue
                     param_dict[key] = parameter_def[key]
 
-            # START: Standard function
-            if function_name == StandardFunctionsDefinition.HIC15:
-                return StandardFunction.HIC_15(param_dict, self._units, True)
-            elif function_name == StandardFunctionsDefinition.HIC36:
-                return StandardFunction.HIC_15(param_dict, self._units, False)
-            elif function_name == StandardFunctionsDefinition.BRIC:
-                return StandardFunction.bric(param_dict, self._units)
-            elif function_name == StandardFunctionsDefinition.A3MS:
-                return StandardFunction.a3ms(param_dict, self._units)
-            elif function_name == StandardFunctionsDefinition.NIJ:
-                return StandardFunction.nij(param_dict, self._units)
-            elif function_name == StandardFunctionsDefinition.VC:
-                return StandardFunction.vc(param_dict, self._units)
-            elif function_name == StandardFunctionsDefinition.TIBIA_INDEX:
-                return StandardFunction.tibia_index(param_dict, self._units)
-            elif function_name == StandardFunctionsDefinition.CFC:
-                return StandardFunction.cfc(param_dict, self._units)
-            elif function_name == StandardFunctionsDefinition.RES:
-                return StandardFunction.res(param_dict)
-            elif function_name == StandardFunctionsDefinition.ABS:
-                return StandardFunction.abs(param_dict)
-            elif function_name == StandardFunctionsDefinition.TRANSFORM_TO_ORIGIN:
-                return StandardFunction.transform_2_origin(param_dict)
-            elif function_name == StandardFunctionsDefinition.MAX:
-                return StandardFunction.max(param_dict)
-            elif function_name == StandardFunctionsDefinition.MAX_IN_ROW:
-                return StandardFunction.max_in_row(param_dict)
-            elif function_name == StandardFunctionsDefinition.MIN:
-                return StandardFunction.minimum(param_dict)
-            elif function_name == StandardFunctionsDefinition.MULT:
-                return StandardFunction.multiplication(param_dict)
-            elif function_name == StandardFunctionsDefinition.SUB:
-                return StandardFunction.subtraction(param_dict)
-            elif function_name == StandardFunctionsDefinition.ADD:
-                return StandardFunction.addition(param_dict)
-            elif function_name == StandardFunctionsDefinition.DIVIDE:
-                return StandardFunction.divide(param_dict)
-            elif function_name == StandardFunctionsDefinition.ABS_SUB:
-                return StandardFunction.abs_subtraction(param_dict)
-            elif function_name == StandardFunctionsDefinition.ABS_ADD:
-                return StandardFunction.abs_addition(param_dict)
-            elif function_name == StandardFunctionsDefinition.ABS_SUB_RES:
-                return StandardFunction.abs_subtraction_res(param_dict)
-            elif function_name == StandardFunctionsDefinition.TIME_OF_FIRST_NEGATIVE:
-                return StandardFunction.time_of_first_negative(param_dict)
-            elif function_name == StandardFunctionsDefinition.ABS_MAX:
-                return StandardFunction.max(param_dict, absolute=True)
-            elif function_name == StandardFunctionsDefinition.NIC:
-                return StandardFunction.NIC(a_t1=param_dict["a_T1"],
-                                            a_head=param_dict["a_head"],
-                                            time_=param_dict["time"],
-                                            units=self._units)
-            elif function_name == StandardFunctionsDefinition.uBRIC:
-                return StandardFunction.uBRIC(param_dict, self._units)
-            elif function_name == StandardFunctionsDefinition.ALL_HIC15_AIS3:
-                return StandardFunction.HIC15_AIS3(param_dict)
-            elif function_name == StandardFunctionsDefinition.ALL_BRIC_AIS3:
-                return StandardFunction.BRIC_AIS3(param_dict)
-            elif function_name == StandardFunctionsDefinition.central_differences:
-                return StandardFunction.central_differences(param_dict)
-            elif function_name == StandardFunctionsDefinition.UNIVERSAL:
-                return StandardFunction.object_strain_stress_hist(param_dict)
-            elif function_name == StandardFunctionsDefinition.STRESS_STRAIN_MAX:
-                return StandardFunction.object_stress_strain_elems_max(param_dict)
-            elif function_name == StandardFunctionsDefinition.PERCENTILE:
-                return StandardFunction.object_strain_stress_percentile(param_dict)
-            elif function_name == StandardFunctionsDefinition.SIGMOID:
-                return StandardFunction.ccdf_sigmoid(param_dict)
-            elif function_name == StandardFunctionsDefinition.LINSPACE:
-                return StandardFunction.linspace(param_dict)
-            elif function_name == StandardFunctionsDefinition.FORMAN_RIB_CRITERIA:
-                return StandardFunction.forman_criteria(param_dict)
-            elif function_name == StandardFunctionsDefinition.OBJECT_TIME:
-                return StandardFunction.time_from_object(param_dict)
-            elif function_name == StandardFunctionsDefinition.CCDF_WEIBULL:
-                return StandardFunction.ccdf_weibull(param_dict)
-            elif function_name == StandardFunctionsDefinition.AT_INDEX:
-                return StandardFunction.at_idx(param_dict)
-            elif function_name == StandardFunctionsDefinition.ARGMAX:
-                return StandardFunction.argmax(param_dict)
-            elif function_name == StandardFunctionsDefinition.CSDM:
-                return StandardFunction.csdm(param_dict)
-            # END: Standard functions
-            if self._user_function is not None:
-                if self._check_if_user_function(function_name):
-                    function = getattr(self._user_function, function_name)
-                    return function(param_dict, self._units)
+            procesed_data = self._call_standard_function(function_name, param_dict)
+            if not procesed_data is None:
+                return procesed_data
             else:
                 self._logger.emit(LOGConstants.ERROR[0],
                                   function_name + StandardFunctionsDefinition.ERROR_NOT_STANDARD_FUNCTION)
-                return
 
-        else:  # data to obtain
-            if JsonConstants.VALUE in json_object.keys():
-                return json_object[JsonConstants.VALUE]
+        elif JsonConstants.VALUE in json_object.keys():
+            return np.array(json_object[JsonConstants.VALUE])
 
+        elif JsonConstants.TYPE in json_object.keys():
             data_type = json_object[JsonConstants.TYPE]
             return self._data[data_type].get_data_of_defined_json(json_object, data_offsets)
 
-    def _check_if_user_function(self, function_name):
-        """
-        :param function_name:
-        :return bool:
-        """
-        attributes = inspect.getmembers(self._user_function, predicate=inspect.isfunction)
-        if function_name in [att[0] for att in attributes]:
-            return True
-        return False
+        else:
+            assert False
 
     def init_plugin_data(self, update):
         """
+
         :param update:
         :return:
         """
         if self._data is None or update:
             self._data = {data: DataContainer.get_data(data) for data in self._data_requirements}
             for data_name in self._data.keys():
-                # if self._code_type == CodeType.MADYMO:
-                #     self._data[data_name].set_madymo_data()
-                #     self._data[data_name].clean_channel_names()
-                #     continue
                 if self._data[data_name] is None:
                     self._logger.emit(LOGConstants.ERROR[0], data_name + LoggerERROR.print_statements[1])
                 if not self._data[data_name].read_binout_data():
@@ -229,17 +186,23 @@ class Plugin(object):
         get sample offset defined between start and end time
 
         :param param_dict:
-
         :return sample offset:
         """
         start_time = param_dict[PluginsParamDictDef.START_TIME] if PluginsParamDictDef.START_TIME in param_dict \
-                        and param_dict[PluginsParamDictDef.START_TIME] != "None" else None
+                                                                   and param_dict[
+                                                                       PluginsParamDictDef.START_TIME] != "None" else None
         end_time = param_dict[PluginsParamDictDef.END_TIME] if PluginsParamDictDef.END_TIME in param_dict \
-                        and param_dict[PluginsParamDictDef.END_TIME] != "None" else None
+                                                               and param_dict[
+                                                                   PluginsParamDictDef.END_TIME] != "None" else None
 
         sample_offsets = []
+        data_types_in_json = []
+        self._dynasaur_definitions.get_all_data_types_from_json(d=param_dict["dynasaur_json"], ls=data_types_in_json)
         for key in self._data.keys():
-            if key == ObjectConstantsForData.VOLUME:
+            if key not in data_types_in_json:
+                continue
+
+            if key == "VOLUME":
                 continue
 
             if start_time is not None and end_time is not None:
@@ -261,6 +224,7 @@ class Plugin(object):
 
             elif start_time is None and end_time is not None:
                 indices = np.argwhere(self._data[key].get_interpolated_time() <= end_time * self._units.second())
+
             else:
                 indices = np.array([np.arange(0, len(self._data[key].get_interpolated_time()))]).transpose()
 
@@ -287,7 +251,7 @@ class Plugin(object):
                     param_dict[key] = parameter_def[key]
         else:  # data to obtain
             if JsonConstants.VALUE in json_object.keys():
-                return json_object[JsonConstants.VALUE]
+                return np.array(json_object[JsonConstants.VALUE])
             elif "strain_stress" in json_object.keys():
                 self._sample_types.append(json_object[JsonConstants.TYPE])
                 return json_object["strain_stress"]
@@ -308,5 +272,32 @@ class PluginInterface(metaclass=abc.ABCMeta):
         """
 
     def calculate(self, param_dict):
+        """
+
+        :param param_dict:
+        :return:
+        """
         param_dict_data = self._dynasaur_definitions.get_param_dict_from_command(command=param_dict)
         self._calculate_and_store_results(param_dict_data)
+
+
+    def get_object_data(self, type_, id_, strain_stress, index, channel, data_offset):
+        """
+
+        :param type_:
+        :param id:
+        :param strain_stress:
+        :param data_offset:
+        :return:
+        """
+        # print(self._data)
+        # part_ids = self._data[type_]._dynasaur_definitions._objects[id]._parts.keys()
+        if type_ == "OBJECT":
+            return self._data[type_].get_data_of_defined_json(
+                json_object={"type": type_, "ID": id_, "strain_stress": strain_stress},
+                data_offset=[(type_, data_offset[0], data_offset[1])])
+
+        else:
+            return self._data[type_].get_data_of_defined_json(
+                json_object={"type": type_, "ID": id_, "array": ["(" + str(index) + "," + str(channel) + ")"]},
+                data_offsets=[(type_, data_offset[0], data_offset[1])])
