@@ -134,6 +134,7 @@ class TestConstants:
 
 class ObjectConstantsForData:
     ELEMENT = "ELEMENT"
+    AIRBAG = "AIRBAG"
     ELEMENTOBJECT = "OBJECT"
     CROSS_SECTION = "CROSS_SECTION"
     DISCRETE = "DISCRETE"
@@ -144,16 +145,6 @@ class ObjectConstantsForData:
     ENERGY_GLOBAL = "ENERGY_GLOBAL"
     DISBOUT = "DISBOUT"
     DISBOUT_PART = "DISBOUT_PART"
-    MADYMO = "MADYMO"
-    VOLUME = "VOLUME"
-    STRAIN = "STRAIN"
-    STRESS = "STRESS"
-
-
-
-# class CodeType:
-#     MADYMO = "MADYMO"
-#     BINOUT = "LS_DYNA"
 
 
 class JsonConstants:
@@ -215,54 +206,7 @@ class DataPluginConstants:
 class StandardFunctionsDefinition:
     HIC15 = "HIC_15"
     HIC36 = "HIC_36"
-    BRIC = "BrIC"
-    TIME_OF_FIRST_NEGATIVE = "time_of_first_negative"
-    A3MS = "a3ms"
-    NIJ = "nij"
-    VC = "vc"
-    TIBIA_INDEX = "tibia_index"
-    CFC = "cfc"
-    RES = "res"
-    ABS = "abs"
-    TRANSFORM_TO_ORIGIN = "transform2origin"
-    MAX = "max"
-    MIN = "min"
-    MULT = "mult"
-    SUB = "sub"
-    ADD = "add"
-    DIVIDE = "divide"
-    ABS_SUB = "abs_sub"
-    ABS_ADD = "abs_add"
-    DOUBLE_ABS_SUB_RES = "double_abs_sub_res"
-    ABS_SUB_RES = "abs_sub_res"
-    ABS_MAX = "absmax"
     ERROR_NOT_STANDARD_FUNCTION = " is not a standard or user function"
-    NIC = "NIC"
-    VEL_NODE = "VEL_NODE" 
-    VEL_NODE_MAX = "VEL_NODE_MAX"
-    ABS_MAX_VALUE = "abs_max_value"
-    THOR_Abdomen_Deflection = "THOR_Abdomen_Deflection"
-    THOR_TCI_Rmax = "THOR_TCI_Rmax"
-    uBRIC = "uBRIC"
-    ALL_HIC15_AIS3 = "HIC15_AIS3"
-    ALL_BRIC_AIS3 = "BRIC_AIS3"
-    minimum_of_four = "minimum_of_four"
-    maximum_of_four = "maximum_of_four"
-    RES_ACC_from_XYZ_Velocities = "RES_ACC_from_XYZ_Velocities"
-    central_differences = "central_differences"
-    UNIVERSAL = "universal"
-    STRESS_STRAIN_MAX = "stress_strain_max"
-    OBJECT_TIME = "object_time"
-
-    PERCENTILE = "percentile"
-    SIGMOID = "sigmoid"
-    CSDM = "csdm"
-    FORMAN_RIB_CRITERIA = "forman_rib_criteria"
-    CCDF_WEIBULL = "ccdf_weibull"
-    LINSPACE = "linspace"
-    AT_INDEX = "at_index"
-    ARGMAX = "argmax"
-    MAX_IN_ROW = "max_in_row"
     FUNCTION_NAME = "function_name"
 
 
